@@ -2,14 +2,14 @@
 Primary entry point.
 
 TODO:
-  1) Get output of files that need to be transformed.
-  2) Give a number, number of lines, packages, etc.
-  3) Git hook that won't allow non python 2/3 code to be pushed.
+  1) Summaries; number of lines per package, etc.
 """
+from __future__ import print_function
+
 import argparse
 import os
+import re
 import subprocess
-
 import sys
 
 from futurizer import futurize_code
@@ -40,9 +40,10 @@ def get_all_python_files(root):
     return python_files
 
 
-def get_python_files(diff=False):
+def get_python_files(diff=False, ignore=None):
     """
     :type diff: bool
+    :type ignore: list or None
     :rtype: list of str
     """
     if diff:
@@ -52,14 +53,24 @@ def get_python_files(diff=False):
             sys.exit(0)
     else:
         python_files = get_all_python_files(os.getcwd())
+
+    if ignore:
+        not_ignored = []
+        for python_file in python_files:
+            for ignore_pattern in ignore:
+                if not re.match(ignore_pattern, python_file):
+                    not_ignored.append(python_file)
+        python_files = not_ignored
+
     return python_files
 
 
-def python3_lint(diff=False):
+def python3_lint(diff=False, ignore=None):
     """
     :type diff: bool
+    :type ignore: list or None
     """
-    python_files = get_python_files(diff=diff)
+    python_files = get_python_files(diff=diff, ignore=ignore)
     # Rules I probably want: fix_xrange
     # Rules I want to avoid: list(Dict.items())
     # `dict`: We want to avoid using this initially because it makes us do things like list(keys()), but without it
@@ -82,8 +93,9 @@ def main():
     """
     parser = argparse.ArgumentParser(description='Run the Py 2/3 coverage report.')
     parser.add_argument('--diff', action='store_true', default=False, help='Run report on the diff only.')
+    parser.add_argument('--ignore', action='append', default=[], help='Regex patterns for ignoring files from linting.')
     args = parser.parse_args()
-    python3_lint(diff=args.diff)
+    python3_lint(diff=args.diff, ignore=args.ignore)
 
 
 if __name__ == '__main__':
